<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr_TR">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seç</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Pencere çerçevesini kaldır</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Dikey çevir</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Yatay çevir</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Ters çevir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gri</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Siyah-ve-beyaz</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Pencereye Geç</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Tam Ekrana Geç</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Pencereye Geç</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Tam Ekrana Geç</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Kurulum başarılı oldu.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Bu pencereyi kapatın ve vokoscreenNG&apos;yi yeniden başlatın.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>vokoscreenNG ile iyi eğlenceler</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seç</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Dosya yöneticisi bulunamadı</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Kayıt başlatılmadı, yeterli boş disk alanı yok.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Boş disk alanı sınırına ulaşıldı.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Boş disk alanı sınırı</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabayt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Kayıt durduruldu, yeterli boş disk alanı yok.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Pencere</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Dosya yöneticisi bulunamadı</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kaynak kodu</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Web Sayfası</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Çeviriler</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Bağış</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seç</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Bölge</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Bölge</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Dosya yöneticisi bulunamadı</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Devam</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Büyüt</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Devam</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Büyüt</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Bir veya daha fazla aygıt seç</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Diyalog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Yatay çevir</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Dikey çevir</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Ters çevir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gri</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Siyah-ve-beyaz</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Pencere çerçevesini kaldır</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kamera ayarları</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Bölge</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Büyüt</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Geri sayım</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Video boyutu:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Boş disk alanı:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Bilgilendirme</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Kayıt Süresi:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Kare sayısı</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Video çözücü</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Ses çözücü</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kalite</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Fare imlecini kaydetme</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Saat</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Dakika</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Zamanlayıcıyı başlat</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Sonra kaydı durdur</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Saat</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Dakika</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Saniye</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video yolu</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Boş disk alanı sınırı</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Sistem tepsisinde göster</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Kayıttan önce biraz bekle</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Güncellemeleri ara</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Mevcut</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Mevcut değil</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Başlat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Devam</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Klasör</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Ters çevir</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gri</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Son kaydı oynat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasörü aç</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Kayıt başladığında simge durumuna küçült</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Simge durumunda başlat</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Yatay çevir</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Dikey çevir</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Siyah-ve-beyaz</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Pencere çerçevesini kaldır</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Bağış</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Bir sonraki başlangıçta tüm ayarları sıfırla</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Resimlerin telif hakkı ve lisans</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabayt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Ekran alıntılama</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Oynatıcı</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Günlük</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Otomatik olarak</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Sekmelerin ekran görüntülerini kaydet</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Lisans bilgisi</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>AÇ</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>KAPAT</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Genel klavye kısayolları</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Atanan kısayol tuşları.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Klavye kısayolu atanmamış veya birden fazla atanmış.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Atanmış görünüyor ancak çalışmıyorsa başka bir program tarafından kullanılıyordur.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Ekrançıktısı</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Resim yolu</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Bu pencereyi gizle</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Kayıttan önce geri say</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Resimlerin telif hakkı ve lisans</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Dosya Aç</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Tam Ekran</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Önceki çerçeve</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Sonraki çerçeve</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sessiz</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menüyü taşı</translation>
    </message>
</context>
</TS>